pub fn rename(
doc: &DocumentState,
position: Position,
new_name: String,
uri: &Url,
) -> Option<WorkspaceEdit>Expand description
Handle rename request.
Finds all definitions and references with the given name and returns a workspace edit that renames them all.